@@ -12,11 +12,11 @@ Data::Text - Class to handle text in an OO way
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -118,6 +118,10 @@ Returns the length of the text.
 sub length {
 	my $self = shift;
 
+	if(!defined($self->{'text'})) {
+		return 0;
+	}
+
 	return length($self->{'text'});
 }
 
